import 'dart:async';

import 'package:flutter/material.dart';
import 'package:flutter/services.dart';

class AssestPlatformChannel extends StatefulWidget {
  @override
  _AssestPlatformChannelState createState() => _AssestPlatformChannelState();
}

class _AssestPlatformChannelState extends State<AssestPlatformChannel> {
  static const MethodChannel methodChannel =
      MethodChannel('GMAssetsMethodChannelName');
  static const EventChannel eventChannel =
      EventChannel('GMAssetsEventChannelName');

  String _batteryLevel = 'Battery level: unknown.';
  Object _imageData;


  Future<void> _editPortrait() async {
    String batteryLevel;
    try {
      final int result = await methodChannel.invokeMethod('editPortrait');
      batteryLevel = 'Battery level: $result%.';
    } on PlatformException {
      batteryLevel = 'Failed to get battery level.';
    }
    setState(() {
      _batteryLevel = batteryLevel;
    });
  }

  @override
  void initState() {
    super.initState();
    eventChannel.receiveBroadcastStream().listen(_onEvent, onError: _onError);
  }

  void _onEvent(Object event) {
    _imageData = event;
    print(event.runtimeType);
    Image.memory(event);
    setState(() {
    });
  }

  void _onError(Object error) {
    setState(() {
    });
  }

  @override
  Widget build(BuildContext context) {
    return Material(
      child: Scaffold(
        appBar: AppBar(
          title: Text('editPortrait test'),
        ),
        body: Center(
          child: Column(
            mainAxisAlignment: MainAxisAlignment.spaceEvenly,
            children: <Widget>[
              Column(
                mainAxisAlignment: MainAxisAlignment.center,
                children: <Widget>[
                  Text(_batteryLevel, key: const Key('editPortrait')),
                  Padding(
                    padding: const EdgeInsets.all(16.0),
                    child: RaisedButton(
                      child: const Text('editPortrait'),
                      onPressed: _editPortrait,
                    ),
                  ),
                  Container(
                    color: Colors.pink[300],
                    width: 300,
                    height: 300,
                    child: _imageWidget()
                  )
                ],
              ),
            ],
          ),
        ),
      ),
    );
  }

  Widget _imageWidget(){
    if (_imageData != null) {
      return Image.memory(_imageData,
                      color: Colors.purple,
                      width: 200,
                      height: 200,
                    );
    }else{
      return Text('i am not image');
    }
  }

}
